import { Modal } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import React, { Dispatch, SetStateAction } from 'react';

type Dispatcher<S> = Dispatch<SetStateAction<S>>;

interface ICustomModalProps {
  isOpen: boolean;
  setIsOpen: Dispatcher<boolean>;
  children: React.ReactNode;
  customStyle: { backgroundColor?: string; padding?: string };
}

const useStyles = makeStyles((theme) => ({
  modal: {
    backgroundColor: 'transparent',
    margin: '7% auto',
    padding: 'none',
    border: 'none',
    width: '85%',
    [theme.breakpoints.down('sm')]: {
      margin: '3% auto',
      width: '95%',
    },
  },
  modalContent: (customStyle: ICustomModalProps['customStyle']) => ({
    ...{
      backgroundColor: customStyle.backgroundColor || 'theme.palette.background.paper',
      border: 'none',
      padding: customStyle.padding || 'none',
      boxShadow: theme.shadows[5],
      '&:focus': {
        outline: 'none',
      },
    },
  }),
}));

export const CustomModal = ({
  isOpen,
  setIsOpen,
  customStyle = {},
  children,
}: ICustomModalProps) => {
  const classes = useStyles(customStyle);

  const handleClose = () => {
    setIsOpen(false);
  };

  const body = <div className={classes.modalContent}>{children}</div>;

  return (
    <div>
      <Modal
        className={classes.modal}
        open={isOpen}
        onClose={handleClose}
        aria-labelledby="custom-modal"
        aria-describedby="custom-modal"
      >
        {body}
      </Modal>
    </div>
  );
};

export default CustomModal;
